@@ -81,7 +81,7 @@ class SaferPayBackend(object):
                 except Exception:
                     pass # this is already logged in payment_complete
             order.save()  # force order.modified to be bumped (we rely on this in the "thank you" view)
-            return HttpResponseRedirect(reverse(settings.SUCCESS_URL_NAME))
+            return self.success(request)
         return self.failure(request)
 
     def cancel(self, request):
@@ -102,6 +102,9 @@ class SaferPayBackend(object):
              'order_name': self.shop.get_order_short_name(order)
         }, context_instance=RequestContext(request))
 
+    def success(self, request):
+        return HttpResponseRedirect(self.shop.get_finished_url())
+
     def get_urls(self):
         return patterns('',
             url(r'^$', self.pay, name='saferpay'),
